## Script (Python) "add_groupspace_services"
##bind container=container
##bind context=context
##bind namespace=
##bind script=script
##bind subpath=traverse_subpath
##parameters=
##title=Add group space services
##

# GroupSpace Areas are added here if this is configures
# At the bottom of the script, there are examples of how to add services
# like a default PloneChat when a GroupSpace is added.

groupspace = context

# Public
#
# Documents that have been elaborated by the group, and are now officially
# available for the general public. GroupMembers can not add these documents,
# Publishing here is done by the GroupAdmin only. GroupAdmin and GroupLader
# can paste documents here, or create new documents.
#
# Shared
#
# Shared folder for GroupMembers only. Anonymous and Member can't access
# or edit here.
#
# Test
#
# A Folder for testing purposes. For example to allow people to familiarize
# themselves with the available tools without disturbing anyone in the other
# GroupSpace areas. Documents here are private to the GroupMembers adding them.
#
# Box
#
# This is a place where GroupMembers can depoist their documents for review
# by the GroupAdmin. The GroupAdmin is the only one who has the right to see
# and work on the content inside. GroupMembers can only add their own documents
# with copy and paste.
#
# Resources
#
# Documents placed in the resources folder are available for the GroupMembers
# as read-only versions. Only the GroupAdmin can modify and add documents here.

if context.portal_properties.grufspaces_properties.use_groupspace_areas==1:

    area_folder_workflow_mappping = {'Public':'groupspace_folder_published_workflow',
                                     'Shared':'groupspace_folder_shared_workflow',
                                     'Test':'groupspace_folder_test_workflow',
                                     'Box':'groupspace_folder_submit_workflow',
                                     'Resources':'groupspace_folder_intra_workflow'}
    
    area_content_workflow_mappping = {'Public':'groupspace_content_published_workflow',
                                      'Shared':'groupspace_content_shared_workflow',
                                      'Test':'groupspace_content_test_workflow',
                                      'Box':'groupspace_content_submit_workflow',
                                      'Resources':'groupspace_content_intra_workflow'}

    area_policy_title = {'Public':'Public Content Policy',
                         'Shared':'Shared Content Policy',
                         'Test':'Test Content Policy',
                         'Box':'Box Content Policy',
                         'Resources':'Resources Content Policy'}

    area_policy_description = {'Public':'Public content only editable by GroupAdmin',
                               'Shared':'Shared content editable by GroupMembers',
                               'Test':'Test content editable by the Owner',
                               'Box':'Box content addable and viewable by Owner and only editable by GroupAdmin',
                               'Resources':'Resources content only addable by GroupAdmins'}
    
    add_meta_type="Factory-based Type Information"
    if context.portal_migration.getInstanceVersion()>="2.1":
        area_type = 'ATContentTypes: ATFolder (ATFolder)'
        add_meta_type="Factory-based Type Information with dynamic views"
    elif 'ATFolder' in context.portal_types.objectIds():
        area_type = 'ATContentTypes: ATFolder'
    else:
        area_type = 'CMFPlone: Plone Folder'

    props = context.portal_properties.site_properties

    for new_type in ('Public','Shared','Resources','Test','Box'): 
        use_folder_tabs = list(props.use_folder_tabs)

        new_id = new_type.lower()
        if 'GroupSpaceArea' + new_type in context.portal_types.objectIds():
            pass
        else:
            context.portal_types.manage_addTypeInformation(add_meta_type=add_meta_type,
                                                           id = 'GroupSpaceArea' + new_type,
                                                           typeinfo_name=area_type,)
            typeinfo = getattr(context.portal_types, 'GroupSpaceArea' + new_type)
            try:
                typeinfo.manage_changeProperties({"global_allow":0})
            except:
                typeinfo.manage_changeProperties(global_allow=0) # Doesn't work with Plone 2.0.5
            context.portal_workflow.setChainForPortalTypes(['GroupSpaceArea' + new_type], area_folder_workflow_mappping[new_type])
        if 'groupspacearea_' + new_id + '_workflow_policy' in context.portal_placeful_workflow.objectIds():
            pass
        else:
            context.portal_placeful_workflow.manage_addWorkflowPolicy(id = 'groupspacearea_' + new_id + '_workflow_policy',
                                                           workflow_policy_type='default_workflow_policy (Simple Policy)')
            policy = getattr(context.portal_placeful_workflow, 'groupspacearea_' + new_id + '_workflow_policy')
            policy.setDefaultChain([area_content_workflow_mappping[new_type]])
            policy.setTitle(area_policy_title[new_type])
            policy.setDescription(area_policy_description[new_type])

        # Action Tabs should be shown
        if 'GroupSpaceArea' + new_type not in use_folder_tabs:
            use_folder_tabs.append('GroupSpaceArea' + new_type)
            props.manage_changeProperties({'use_folder_tabs':tuple(use_folder_tabs)})
    
        if not hasattr(context, new_id):
            context.portal_types.constructContent('GroupSpaceArea' + new_type,
                                                  groupspace, 
                                                  id=new_id,
                                                  title=new_type)

        space = getattr(groupspace, new_id)
        if not hasattr(space, '.wf_policy_config'):
            space.manage_addProduct['CMFPlacefulWorkflow'].manage_addWorkflowPolicyConfig()
        conf = getattr(space, '.wf_policy_config')
        conf.setPolicyIn('groupspacearea_' + new_id + '_workflow_policy')
        conf.setPolicyBelow('groupspacearea_' + new_id + '_workflow_policy')
        
"""
# GroupSpace Services 
# - experiment with the following code to add services you need:

#try:
#    # Create wiki
#    new_id = 'wiki'
#    private.invokeFactory(type_name='I18NFolder', id=new_id)
#    obj = getattr(private, new_id)
#    obj.edit(title='Wiki', description='', lang_code='en')
#    obj.edit(title='Wiki', description='', lang_code='fr')
#    context.portal_workflow.doActionFor(obj, 'publish')
#    wiki = obj 

#    # Add default wiki page
#    wiki.invokeFactory(type_name='Wiki Page', id='FrontPage', title='Frontpage')

#except:
#    pass

#try:
#    
#    # Create chat
#    new_id = 'chat'
#    private.invokeFactory(type_name='PloneChat', id=new_id, title='chat')
#    obj = getattr(private, new_id)
#    obj.manage_editPloneChat(moderation = 0,
#                             refresh_rate = 10,
#                             time_format = '%H:%M:%S')
#    context.portal_workflow.doActionFor(obj, 'publish')    
#except:
#    pass

#try:
#    # Create poll
#    new_id = 'poll'
#    private.invokeFactory(type_name='PlonePopoll', id=new_id, title='Group activity')
#    obj = getattr(private, new_id)
#    question = 'Feeling about group activity ?'
#    choices = ['nothing happening', 'starting to move', 'good', 'excellent']
#    obj.setPollOptions(question = question,
#                       choices = choices,
#                       check_multi = 0)
#    obj.enable()
#    context.portal_workflow.doActionFor(obj, 'publish')
#except:
#    pass
"""




