# -*- coding: utf-8 -*-
## GrufSpaces
## Group environments for elaborating and exchanging information
## Copyright (C)2006 Ingeniweb

## This program is free software; you can redistribute it and/or modify
## it under the terms of the GNU General Public License as published by
## the Free Software Foundation; either version 2 of the License, or
## (at your option) any later version.

## This program is distributed in the hope that it will be useful,
## but WITHOUT ANY WARRANTY; without even the implied warranty of
## MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
## GNU General Public License for more details.

## You should have received a copy of the GNU General Public License
## along with this program; see the file COPYING. If not, write to the
## Free Software Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.

# $Id: testPloneCollabSpaceInterface.py 23544 2006-05-16 09:59:45Z roeder $

import os, sys
if __name__ == '__main__':
    execfile(os.path.join(sys.path[0], 'framework.py'))

from Products.GrufSpaces.tests import grufspacestestcase
from AccessControl import getSecurityManager

class TestPloneCollabSpaceRolesReg(grufspacestestcase.GrufSpacesTestCase):
    "Test methods of the CollabSpace class - roles registration."

    def testBasicInfo(self):
        self.setRoles(['Manager', 'Member']) 
        self.qi = self.portal.portal_quickinstaller
        self.qi.installProduct('GrufSpaces')
        self.portal.invokeFactory('GroupSpace', 'pcs')
        self.pcs = self.portal.pcs
        self.securityManager = getSecurityManager()

        self.assertEquals('pcs', self.pcs.getId())
        self.assertEquals('GroupSpace', self.pcs.Type())
        self.assertEquals('GroupSpace', self.pcs.meta_type)
        self.assertEquals('GroupSpace', self.pcs.getTypeInfo().Metatype())
        self.pcs.edit(title='PCS', description='My Plone Collab Space')
        self.assertEquals('PCS', self.pcs.Title())
        self.assertEquals('My Plone Collab Space', self.pcs.Description())
        pt = self.portal.portal_types
        fti = pt.getTypeInfo('GroupSpace')

class TestPloneCollabSpaceUserAssignment(grufspacestestcase.GrufSpacesTestCase):
    "Test methods of the CollabSpace class - user assignment."

    def afterSetUp(self):
        self.loginAsPortalOwner()
        self.qi = self.portal.portal_quickinstaller
        self.qi.installProduct('GrufSpaces')
        self.portal.invokeFactory('GroupSpace', 'pcs')
        self.pcs = self.portal.pcs
        self.user1 = self.createMember('user1', 'abcd1', 'abc1@domain.tld')
        self.user2 = self.createMember('user2', 'abcd2', 'abc2@domain.tld')
        self.user3 = self.createMember('user3', 'abcd3', 'abc3@domain.tld')
        self.user4 = self.createMember('user4', 'abcd4', 'abc4@domain.tld')

    # still missing:
    # - check catalog updates on local role changes

    def testassignCollabRoleToUser(self):
        self.pcs.assignCollabRoleToUser('GroupMember', 'user1')
        roles = self.user1.getRolesInContext(self.pcs)
        self.failUnless('GroupMember' in roles,
            'user1 has not got the local role "GroupMember" - roles: %s' % `roles`)

    def testassignCollabRoleToUserUserNotExists(self):
        self.assertRaises(ValueError, self.pcs.assignCollabRoleToUser, 'GroupMember', 'nobody')

    def testassignCollabRoleToUserNotRegistered(self):
        self.assertRaises(ValueError, self.pcs.assignCollabRoleToUser, 'Reviewer', 'user1')

    def testGetCollabUsers(self):
        self.pcs.assignCollabRoleToUser('GroupMember', 'user1')
        users = self.pcs.getCollabUsers()
        self.assertEquals(('user1',), users)

    def testGetCollabUsersWithSelection(self):
        self.pcs.assignCollabRoleToUser('GroupMember', 'user1')
        self.pcs.assignCollabRoleToUser('GroupAdmin', 'user2')
        self.pcs.assignCollabRoleToUser('GroupVisitor', 'user3')
        self.pcs.assignCollabRoleToUser('GroupLeader', 'user4')
        users = self.pcs.getCollabUsers('GroupMember')
        self.assertEquals(('user1',), users)
        users = self.pcs.getCollabUsers('GroupAdmin')
        self.assertEquals(('user2',), users)
        users = self.pcs.getCollabUsers('GroupVisitor')
        self.assertEquals(('user3',), users)
        users = self.pcs.getCollabUsers('GroupLeader')
        self.assertEquals(('user4',), users)


    def testGetCollabUserObjects(self):
        self.pcs.assignCollabRoleToUser('GroupMember', 'user1')
        users = self.pcs.getCollabUserObjects()
        self.assertEquals(len(users),1)
        user_info = users[0]
        user_type, user = user_info
        self.assertEquals(user_type, 'user')
        self.assertEquals(user.getUserName(), 'user1')

    def testGetCollabUserDictionary(self):
        self.pcs.assignCollabRoleToUser('GroupMember', 'user1')
        userdict = self.pcs.getCollabUserDictionary()
        self.assertEquals({'GroupMember': ('user1',)}, userdict)

    def testassignCollabRoleToGroup(self):
        pm = self.portal.portal_membership
        self.group1 = self.createGroup('group1')
        self.group1.addMember('user1')
        self.pcs.assignCollabRoleToGroup('GroupMember', self.group1.getUserName())
        roles = self.user1.getRolesInContext(self.pcs)
        self.failUnless('GroupMember' in roles,
            'user1 has not got the local role "GroupMember" - roles: %s' % `roles`)
        self.failUnless(pm.checkPermission('Add portal content', self.pcs),
            'user1 has not got the "Add portal content" permission')
        self.login('user1')
        self.pcs.invokeFactory('Document', 'td1')
        self.assertEquals(['td1'], self.pcs.contentIds())
        self.failUnless(pm.checkPermission('Add portal content', self.pcs),
            'user1 has not got the "Add portal content" permission')

    def testRemoveCollabRoleFromGroup(self):
        pm = self.portal.portal_membership
        self.group1 = self.createGroup('group1')
        self.group1.addMember('user1')
        self.pcs.assignCollabRoleToGroup('GroupMember', self.group1.getUserName())
        self.pcs.removeCollabRoleFromGroup('GroupMember', self.group1.getUserName())
        roles = self.user1.getRolesInContext(self.pcs)
        self.failUnless(not 'GroupMember' in roles,
            'user1 has got the local role "GroupMember" - roles: %s' % `roles`)
        self.login('user1')
        error=""
        try:
            self.pcs.invokeFactory('Document', 'td1')
        except:
            error="Unauthorized"
        self.assertEquals(error, "Unauthorized")
        self.assertEquals([], self.pcs.contentIds())
        self.failIf(pm.checkPermission('Add portal content', self.pcs),
            'user1 has not got the "Add portal content" permission')

    def testGetCollabUserObjectsGroup(self):
        self.group1 = self.createGroup('group1')
        self.pcs.assignCollabRoleToGroup('GroupMember', self.group1.getUserName())
        users = self.pcs.getCollabUserObjects()
        self.assertEquals(len(users),1)
        user_info = users[0]
        user_type, user = user_info
        self.assertEquals(self.group1.getUserName(), user.getUserName())
        self.assertEquals('group1', user.getUserName())
        self.failUnless(hasattr(user, 'getGroupMembers'))

    def createMember(self, id, pw, email, roles=('Member',)):
        pr = self.portal.portal_registration
        member = pr.addMember(id, pw, roles, properties={ 'username': id, 'email' : email })
        return member

    def createGroup(self, id):
        pg = self.portal.portal_groups
        pg.addGroup(id, '', (), ())
        return pg.getGroupById(id)


if __name__ == '__main__':
    framework()
else:
    # While framework.py provides its own test_suite()
    # method the testrunner utility does not.
    from unittest import TestSuite, makeSuite
    def test_suite():
        suite = TestSuite()
        suite.addTest(makeSuite(TestPloneCollabSpaceRolesReg))
        suite.addTest(makeSuite(TestPloneCollabSpaceUserAssignment))
        return suite
